library ieee;
use ieee.std_logic_1164.all;

entity InOutGen is
GENERIC (DataRange	: integer);
port
 (
  ClockIn,          																														-- General Clock
  nResetIn,         																														-- General Reset active low
  nEnableIn    	: in    std_logic;        																			-- Active 0 for read from FPGA
  DataIn     		: in    std_logic_vector(DataRange downto 0);                   -- Data for trnsport from FPGA to DataIO
  DataOutValid  : out   std_logic;                   														-- Data for trnsport from DataIO to FPGA valid
  DataOut    		: out   std_logic_vector(DataRange downto 0);                   -- Data for trnsport from DataIO to FPGA
  DataIO     		: inout std_logic_vector(DataRange downto 0)                    -- External Data Bus
 );
end InOutGen;

architecture ArchInOutGen of InOutGen is

begin

InOutProcess:
process (ClockIn,nEnableIn)
begin
 if nEnableIn = '0' then
  DataIO  		<= DataIn;
 else
  DataIO 			<= (others => 'Z');
 end if;
 if ClockIn'event and ClockIn = '1'then
	case nResetIn is
	 when '0' =>
  	DataOutValid <='0';                   																			-- Data for trnsport from DataIO to FPGA valid
		DataOut 	<= (others => '0');
 	 when others =>
  	DataOutValid 	<= nEnableIn;                   															-- Data for trnsport from DataIO to FPGA valid
		DataOut 			<= DataIO;
	end case;
 end if;
end process InOutProcess;

end ArchInOutGen;



