library ieee;
use ieee.std_logic_1164.all;

entity InOutGen_Tb is

end InOutGen_Tb;

architecture ArchInOutGen_Tb of InOutGen_Tb is

signal Clock,
       DataOutValid                    																					-- Data for trnsport from DataIO to FPGA valid																 		 		 		 		 		 					-- Clock
										: std_logic := '0';
signal nReset,          																												-- General Reset active Low
  		 nEnable         																													-- Active 0 for read from FPGA
										: std_logic := '1';
signal ReadData,                      																					-- Data for transport from FPGA to DataIO
			 WriteData,                      																					-- Data for transport from DataIO to FPGA
			 ExternalData                       																			-- External Data Bus
 										: std_logic_vector(15 downto 0) := (others => '0');

begin
Clock 		<= not Clock after 16.667 nS;     																		-- Clock 30.000 MHz
nReset		<= '1','0' after 50 nS,'1' after 100 nS;         										-- General Reset active Low

InOutGen_UUT : entity work.InOutGen
--GENERIC (DataRange	: integer);
GENERIC MAP (15)
port map
 (
  ClockIn 			=> Clock,      																									-- General Clock
  nResetIn			=> nReset,																											-- General Reset active low
  nEnableIn			=> nEnable,        																							-- Active 0 for read from FPGA
  DataIn   			=> ReadData,                      															-- Data for trnsport from FPGA to DataIO
  DataOutValid  => DataOutValid,                   															-- Data for trnsport from DataIO to FPGA valid
  DataOut     	=> WriteData,                      															-- Data for trnsport from DataIO to FPGA
  DataIO      	=> ExternalData                       													-- External Data Bus
 );

  TestProcess:
 process
 begin
 ReadData <= (others => '0');                      															-- Data for transport from FPGA to DataIO
 nEnable  <= '1';       																												-- Active 0 for read from FPGA
 ExternalData <= (others => 'Z');                       												-- External Data Bus
 wait for	110 nS;
 ExternalData <= X"AAAA";                       																-- External Data Bus
 wait for	100 nS;
 nEnable  <= '0';       																												-- Active 0 for read from FPGA
 ExternalData <= (others => 'Z');                       												-- External Data Bus
 ReadData <= X"A55A";                      																		-- Data for transport from FPGA to DataIO
 wait for	100 nS;
 nEnable  <= '1';       																												-- Active 0 for read from FPGA
 ExternalData <= X"CCCC";                       																-- External Data Bus
 wait for	100 nS;
 nEnable  <= '0';       																												-- Active 0 for read from FPGA
 ReadData <= X"BBBB";                      																		-- Data for transport from FPGA to DataIO
 ExternalData <= (others => 'Z');                       												-- External Data Bus
  wait for	100 nS;
 nEnable  <= '1';       																												-- Active 0 for read from FPGA
 ExternalData <= X"2222";                       																-- External Data Bus
  wait for	100 nS;
 nEnable  <= '0';       																												-- Active 0 for read from FPGA
 ReadData <= X"CDCD";                      																		-- Data for transport from FPGA to DataIO
 ExternalData <= (others => 'Z');                       												-- External Data Bus

 wait;
 end process  TestProcess;

end ArchInOutGen_Tb;



